OC.L10N.register(
    "files_external",
    {
    "External storages" : "Almacenamientos internos",
    "Personal" : "Personal",
    "System" : "Sistema",
    "Grant access" : "Conceder accesu",
    "Error configuring OAuth1" : "Fallu configurando Oauth1",
    "Error configuring OAuth2" : "Fallu configurando OAuth2",
    "Generate keys" : "Xenerar claves",
    "Error generating key pair" : "Fallu xenerando'l par de claves",
    "All users. Type to select user or group." : "Tolos usuarios. Escribe pa seleccionar usuariu o grupu.",
    "(group)" : "(grupu)",
    "Enable encryption" : "Habilitar cifráu",
    "Never" : "Enxamás",
    "Read only" : "Namái llectura",
    "Delete" : "Desaniciar",
    "Delete storage?" : "¿Desaniciar almacenamientu?",
    "Saved" : "Guardáu",
    "Saving..." : "Guardando...",
    "Save" : "Guardar",
    "Empty response from the server" : "Rempuesta balera del sirvidor",
    "Couldn't access. Please log out and in again to activate this mount point" : "Nun pudo accedese. Volvi aniciar sesión p'activar esti puntu de montaxe, por favor",
    "Couldn't get the list of external mount points: {type}" : "Nun pudo consiguise'l llistáu de puntos esternos de montaxe: {type}",
    "There was an error with message: " : "Hebo un fallu col mensaxe:",
    "External mount error" : "Fallu de montaxe esternu",
    "Username" : "Nome d'usuariu",
    "Password" : "Contraseña",
    "Invalid mount point" : "Puntu de montaxe non válidu",
    "%s" : "%s",
    "Secret key" : "Clave secreta",
    "None" : "Dengún",
    "OAuth1" : "OAuth1",
    "App key" : "Clave d'aplicación",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID de veceru",
    "Client secret" : "Veceru secretu",
    "Domain" : "Dominiu",
    "API key" : "clave API",
    "Global credentials" : "Credenciales global",
    "Username and password" : "Nome d'usuariu y contraseña",
    "RSA public key" : "Clave RSA pública",
    "Public key" : "Clave pública",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Depósitu",
    "Hostname" : "Nome d'agospiu",
    "Port" : "Puertu",
    "Region" : "Rexón",
    "Enable SSL" : "Habilitar SSL",
    "Enable Path Style" : "Habilitar Estilu de ruta",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Subcarpeta remota",
    "Host" : "Sirvidor",
    "Local" : "Llocal",
    "Location" : "Llocalización",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Raíz",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Compartir",
    "Show hidden files" : "Amosar ficheros anubríos",
    "SMB / CIFS using OC login" : "SMB / CIFS usando accesu OC",
    "Username as share" : "Nome d'usuariu como Compartición",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Nome del serviciu",
    "Name" : "Nome",
    "Storage type" : "Triba d'almacenamientu",
    "Scope" : "Ámbitu",
    "Open documentation" : "Abrir documentación",
    "Folder name" : "Nome de la carpeta",
    "External storage" : "Almacenamientu esternu",
    "Authentication" : "Autenticación",
    "Configuration" : "Configuración",
    "Available for" : "Disponible pa",
    "Add storage" : "Amestar almacenamientu",
    "Advanced settings" : "Axustes avanzaos"
},
"nplurals=2; plural=(n != 1);");
